const fs = require('fs');
const path = require('path');
const os = require('os');
const crypto = require('crypto');

// Uygulamanın verilerini saklayacağı dizini bulma
function getAppDataPath() {
  if (os.platform() === 'win32') {
    return path.join(process.env.APPDATA, 'seyfooksck');  // Windows
  } else if (os.platform() === 'linux' || os.platform() === 'darwin') {
    return path.join(os.homedir(), '.seyfooksck');  // Linux / macOS
  } else {
    throw new Error('Unsupported platform');
  }
}

// Anahtar oluşturma (rastgele bir key üretir)
function generateKey(prefix = '', secret = '', appname = '', keysize = 32) {
  const baseString = prefix + secret + appname;
  const hash = crypto.createHash('sha256');
  hash.update(baseString);
  const rawKey = hash.digest('hex');  // 64 karakterlik bir hash oluşturulacak (SHA-256)

  // Anahtar uzunluğunu keysize ile sınırlayalım
  const truncatedKey = rawKey.slice(0, keysize);
  
  return truncatedKey;
}

// Anahtarı dosyadan okuma veya oluşturma
function readKey(prefix = '', secret = '', appname = '', keysize = 32) {
  const appDataPath = getAppDataPath();
  const keyFilePath = path.join(appDataPath, 'skeyid.json');

  if (!fs.existsSync(appDataPath)) {
    fs.mkdirSync(appDataPath, { recursive: true });  // Eğer dizin yoksa oluştur
  }

  if (!fs.existsSync(keyFilePath)) {
    // Anahtar dosyası yoksa, yeni bir anahtar oluştur
    const key = generateKey(prefix, secret, appname, keysize);
    fs.writeFileSync(keyFilePath, JSON.stringify({ key }));
    return key;
  }

  // Anahtar dosyasını oku
  const data = JSON.parse(fs.readFileSync(keyFilePath, 'utf8'));
  return data.key;
}

// Anahtarı sıfırlama (yeni bir anahtar oluşturma)
function resetKey(prefix = '', secret = '', appname = '', keysize = 32) {
  const appDataPath = getAppDataPath();
  const keyFilePath = path.join(appDataPath, 'skeyid.json');

  const newKey = generateKey(prefix, secret, appname, keysize);
  fs.writeFileSync(keyFilePath, JSON.stringify({ key: newKey }));
  return newKey;
}

// `skeyid` fonksiyonu bir nesne içinde tanımlı olacak şekilde güncelleniyor
function skeyid({ prefix = '', secret = '', appname = '', keysize = 32, command = '' }) {
  if (command === 'reset') {
    return resetKey(prefix, secret, appname, keysize);
  } else {
    return readKey(prefix, secret, appname, keysize);
  }
}

// Modül dışa aktarılıyor
module.exports = { skeyid };
